@@ -12,6 +12,8 @@
 
 #include <iostream>
 #include <string>
+#include <utility>
+#include <vector>
 
 #include "kaldi_native_io/csrc/io-funcs.h"
 #include "kaldi_native_io/csrc/kaldi-matrix.h"
@@ -104,7 +106,8 @@ class BasicHolder {
 
   void Swap(BasicHolder<T> *other) { std::swap(t_, other->t_); }
 
-  bool ExtractRange(const BasicHolder<T> &other, const std::string &range) {
+  bool ExtractRange(const BasicHolder<T> & /*other*/,
+                    const std::string & /*range*/) {
     KALDIIO_ERR << "ExtractRange is not defined for this type of holder.";
     return false;
   }
@@ -112,7 +115,7 @@ class BasicHolder {
   ~BasicHolder() {}
 
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicHolder)
 
   T t_;
 };
@@ -225,8 +228,8 @@ class BasicVectorHolder {
 
   void Swap(BasicVectorHolder<BasicType> *other) { t_.swap(other->t_); }
 
-  bool ExtractRange(const BasicVectorHolder<BasicType> &other,
-                    const std::string &range) {
+  bool ExtractRange(const BasicVectorHolder<BasicType> & /*other*/,
+                    const std::string & /*range*/) {
     KALDIIO_ERR << "ExtractRange is not defined for this type of holder.";
     return false;
   }
@@ -234,7 +237,7 @@ class BasicVectorHolder {
   ~BasicVectorHolder() {}
 
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicVectorHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicVectorHolder)
   T t_;
 };
 
@@ -375,8 +378,8 @@ class BasicVectorVectorHolder {
 
   void Swap(BasicVectorVectorHolder<BasicType> *other) { t_.swap(other->t_); }
 
-  bool ExtractRange(BasicVectorVectorHolder<BasicType> &other,
-                    const std::string &range) {
+  bool ExtractRange(BasicVectorVectorHolder<BasicType> & /*other*/,
+                    const std::string & /*range*/) {
     KALDIIO_ERR << "ExtractRange is not defined for this type of holder.";
     return false;
   }
@@ -384,7 +387,7 @@ class BasicVectorVectorHolder {
   ~BasicVectorVectorHolder() {}
 
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicVectorVectorHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicVectorVectorHolder)
   T t_;
 };
 
@@ -519,8 +522,8 @@ class BasicPairVectorHolder {
 
   void Swap(BasicPairVectorHolder<BasicType> *other) { t_.swap(other->t_); }
 
-  bool ExtractRange(const BasicPairVectorHolder<BasicType> &other,
-                    const std::string &range) {
+  bool ExtractRange(const BasicPairVectorHolder<BasicType> & /*other*/,
+                    const std::string & /*range*/) {
     KALDIIO_ERR << "ExtractRange is not defined for this type of holder.";
     return false;
   }
@@ -528,7 +531,7 @@ class BasicPairVectorHolder {
   ~BasicPairVectorHolder() {}
 
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicPairVectorHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(BasicPairVectorHolder)
   T t_;
 };
 
@@ -575,13 +578,14 @@ class TokenHolder {
 
   void Swap(TokenHolder *other) { t_.swap(other->t_); }
 
-  bool ExtractRange(const TokenHolder &other, const std::string &range) {
+  bool ExtractRange(const TokenHolder & /*other*/,
+                    const std::string & /*range*/) {
     KALDIIO_ERR << "ExtractRange is not defined for this type of holder.";
     return false;
   }
 
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(TokenHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(TokenHolder)
   T t_;
 };
 
@@ -599,7 +603,7 @@ class TokenVectorHolder {
          iter != t.end(); ++iter) {
       KALDIIO_ASSERT(IsToken(*iter));  // make sure it's whitespace-free,
       // printable and nonempty.
-      os << sep <<  *iter;
+      os << sep << *iter;
       sep = " ";
     }
     os << '\n';
@@ -635,13 +639,14 @@ class TokenVectorHolder {
 
   void Swap(TokenVectorHolder *other) { t_.swap(other->t_); }
 
-  bool ExtractRange(const TokenVectorHolder &other, const std::string &range) {
+  bool ExtractRange(const TokenVectorHolder & /*other*/,
+                    const std::string & /*range*/) {
     KALDIIO_ERR << "ExtractRange is not defined for this type of holder.";
     return false;
   }
 
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(TokenVectorHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(TokenVectorHolder)
   T t_;
 };
 
@@ -724,7 +729,7 @@ class KaldiObjectHolder {
   ~KaldiObjectHolder() { delete t_; }
 
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(KaldiObjectHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(KaldiObjectHolder)
   T *t_;
 };
 
@@ -763,13 +768,14 @@ class HtkMatrixHolder {
     std::swap(t_.second, other->t_.second);
   }
 
-  bool ExtractRange(const HtkMatrixHolder &other, const std::string &range) {
+  bool ExtractRange(const HtkMatrixHolder & /*other*/,
+                    const std::string & /*range*/) {
     KALDIIO_ERR << "ExtractRange is not defined for this type of holder.";
     return false;
   }
   // Default destructor.
  private:
-  KALDIIO_DISALLOW_COPY_AND_ASSIGN(HtkMatrixHolder);
+  KALDIIO_DISALLOW_COPY_AND_ASSIGN(HtkMatrixHolder)
   T t_;
 };
 
