@@ -4,8 +4,11 @@
 
 #include "kaldi_native_io/csrc/kaldi-table.h"
 
+#include <string>
+
 #include "kaldi_native_io/csrc/compressed-matrix.h"
 #include "kaldi_native_io/csrc/kaldi-holder.h"
+#include "kaldi_native_io/csrc/kaldi-io.h"
 #include "kaldi_native_io/csrc/kaldi-matrix.h"
 #include "kaldi_native_io/csrc/kaldi-vector.h"
 #include "kaldi_native_io/csrc/matrix-shape.h"
@@ -16,7 +19,8 @@
 namespace kaldiio {
 
 template <class Holder>
-void PybindTableWriter(py::module &m, const std::string &class_name,
+void PybindTableWriter(py::module &m,  // NOLINT
+                       const std::string &class_name,
                        const std::string &class_help_doc = "") {
   using PyClass = TableWriter<Holder>;
 
@@ -31,7 +35,8 @@ void PybindTableWriter(py::module &m, const std::string &class_name,
 }
 
 template <class Holder>
-void PybindSequentialTableReader(py::module &m, const std::string &class_name,
+void PybindSequentialTableReader(py::module &m,  // NOLINT
+                                 const std::string &class_name,
                                  const std::string &class_help_doc = "") {
   using PyClass = SequentialTableReader<Holder>;
   py::class_<PyClass>(m, class_name.c_str(), class_help_doc.c_str())
@@ -48,7 +53,8 @@ void PybindSequentialTableReader(py::module &m, const std::string &class_name,
 }
 
 template <class Holder>
-void PybindRandomAccessTableReader(py::module &m, const std::string &class_name,
+void PybindRandomAccessTableReader(py::module &m,  // NOLINT
+                                   const std::string &class_name,
                                    const std::string &class_help_doc = "") {
   using PyClass = RandomAccessTableReader<Holder>;
   py::class_<PyClass>(m, class_name.c_str(), class_help_doc.c_str())
@@ -62,7 +68,22 @@ void PybindRandomAccessTableReader(py::module &m, const std::string &class_name,
            py::return_value_policy::reference);
 }
 
-void PybindKaldiTable(py::module &m) {
+template <typename Holder>
+void PybindReadSingleItem(py::module &m,  // NOLINT
+                          const std::string &name,
+                          const std::string &help_doc = "") {
+  m.def(
+      name.c_str(),
+      [](const std::string &rxfilename) {
+        Input ki(rxfilename);
+        Holder holder;
+        holder.Read(ki.Stream());
+        return holder.Value();  // Return a copy
+      },
+      py::arg("rxfilename"), help_doc.c_str());
+}
+
+void PybindKaldiTable(py::module &m) {  // NOLINT
   PybindTableWriter<BasicHolder<int32_t>>(m, "_Int32Writer");
   PybindSequentialTableReader<BasicHolder<int32_t>>(m,
                                                     "_SequentialInt32Reader");
@@ -74,6 +95,8 @@ void PybindKaldiTable(py::module &m) {
       m, "_SequentialInt32VectorReader");
   PybindRandomAccessTableReader<BasicVectorHolder<int32_t>>(
       m, "_RandomAccessInt32VectorReader");
+  PybindReadSingleItem<BasicVectorHolder<int32_t>>(
+      m, "read_int32_vector", "Read std::vector<int32_t> for an rxfilename");
 
   PybindTableWriter<BasicVectorVectorHolder<int32_t>>(
       m, "_Int32VectorVectorWriter");
@@ -89,6 +112,14 @@ void PybindKaldiTable(py::module &m) {
   PybindRandomAccessTableReader<BasicPairVectorHolder<int32_t>>(
       m, "_RandomAccessInt32PairVectorReader");
 
+  PybindTableWriter<BasicVectorHolder<int8_t>>(m, "_Int8VectorWriter");
+  PybindSequentialTableReader<BasicVectorHolder<int8_t>>(
+      m, "_SequentialInt8VectorReader");
+  PybindRandomAccessTableReader<BasicVectorHolder<int8_t>>(
+      m, "_RandomAccessInt8VectorReader");
+  PybindReadSingleItem<BasicVectorHolder<int8_t>>(
+      m, "read_int8_vector", "Read std::vector<int8_t> for an rxfilename");
+
   PybindTableWriter<BasicHolder<float>>(m, "_FloatWriter");
   PybindSequentialTableReader<BasicHolder<float>>(m, "_SequentialFloatReader");
   PybindRandomAccessTableReader<BasicHolder<float>>(m,
