@@ -9,7 +9,7 @@
 
 namespace kaldiio {
 
-void PybindKaldiTable(py::module &m);
+void PybindKaldiTable(py::module &m);  // NOLINT
 
 }  // namespace kaldiio
 
