@@ -8,6 +8,8 @@
 #include "kaldi_native_io/python/csrc/kaldi-matrix.h"
 #include "kaldi_native_io/python/csrc/kaldi-table.h"
 #include "kaldi_native_io/python/csrc/kaldi-vector.h"
+#include "kaldi_native_io/python/csrc/matrix-shape.h"
+#include "kaldi_native_io/python/csrc/wave-reader.h"
 
 namespace kaldiio {
 
@@ -17,6 +19,8 @@ PYBIND11_MODULE(_kaldi_native_io, m) {
   PybindKaldiVector(m);
   PybindKaldiMatrix(m);
   PybindCompressedMatrix(m);
+  PybindWaveReader(m);
+  PybindMatrixShape(m);
 }
 
 }  // namespace kaldiio
