@@ -1,14 +1,19 @@
+from pathlib import Path as _Path
+from typing import List
+
+import _kaldi_native_io
 from _kaldi_native_io import (
     CompressionMethod,
     HtkHeader,
     MatrixShape,
     WaveData,
     WaveInfo,
-    _DoubleMatrix as DoubleMatrix,
-    _FloatMatrix as FloatMatrix,
-    read_wave,
-    read_wave_info,
 )
+from _kaldi_native_io import _DoubleMatrix as DoubleMatrix
+from _kaldi_native_io import _DoubleVector as DoubleVector
+from _kaldi_native_io import _FloatMatrix as FloatMatrix
+from _kaldi_native_io import _FloatVector as FloatVector
+from _kaldi_native_io import read_wave, read_wave_info
 
 from .table_types import (
     BoolWriter,
@@ -22,6 +27,7 @@ from .table_types import (
     FloatWriter,
     GaussPostWriter,
     HtkMatrixWriter,
+    Int8VectorWriter,
     Int32PairVectorWriter,
     Int32VectorVectorWriter,
     Int32VectorWriter,
@@ -37,6 +43,7 @@ from .table_types import (
     RandomAccessFloatVectorReader,
     RandomAccessGaussPostReader,
     RandomAccessHtkMatrixReader,
+    RandomAccessInt8VectorReader,
     RandomAccessInt32PairVectorReader,
     RandomAccessInt32Reader,
     RandomAccessInt32VectorReader,
@@ -57,6 +64,7 @@ from .table_types import (
     SequentialFloatVectorReader,
     SequentialGaussPostReader,
     SequentialHtkMatrixReader,
+    SequentialInt8VectorReader,
     SequentialInt32PairVectorReader,
     SequentialInt32Reader,
     SequentialInt32VectorReader,
@@ -69,10 +77,19 @@ from .table_types import (
     SequentialWaveReader,
     TokenVectorWriter,
     TokenWriter,
+    WaveWriter,
 )
 
-from pathlib import Path as _Path
-
 cmake_prefix_path = _Path(__file__).parent / "share" / "cmake"
 del _Path
-__version__ = '1.13'
+
+
+def read_int32_vector(rxfilename: str) -> List[int]:
+    """Read a vector of int32 from an rxfilename"""
+    return _kaldi_native_io.read_int32_vector(rxfilename)
+
+
+def read_int8_vector(rxfilename: str) -> List[int]:
+    """Read a vector of int8 from an rxfilename"""
+    return _kaldi_native_io.read_int8_vector(rxfilename)
+__version__ = '1.17.2'
