@@ -38,10 +38,42 @@ def test_random_access_double_vector_reader():
         assert np.array_equal(ki["b"], np.array([10.5], dtype=np.float64))
 
 
+def test_read_write_single_vector():
+    a = np.array([1, 2], dtype=np.float64)
+    v = kaldi_native_io.DoubleVector(a)
+    v.write(wxfilename="binary.ark", binary=True)
+
+    b = kaldi_native_io.DoubleVector.read("binary.ark")
+    assert np.array_equal(a, b.numpy())
+
+    os.remove("binary.ark")
+
+    a = np.array([1, 2], dtype=np.float64)
+    b = np.array([10.5], dtype=np.float64)
+    with kaldi_native_io.DoubleVectorWriter("ark,scp:v.ark,v.scp") as ko:
+        ko.write("a", a)
+        ko["b"] = b
+
+    """
+    v.scp contains:
+      a v.ark:2
+      b v.ark:30
+    """
+    va = kaldi_native_io.DoubleVector.read("v.ark:2")
+    assert np.array_equal(va.numpy(), a)
+
+    vb = kaldi_native_io.DoubleVector.read("v.ark:30")
+    assert np.array_equal(vb.numpy(), b)
+
+    os.remove("v.scp")
+    os.remove("v.ark")
+
+
 def main():
     test_double_vector_writer()
     test_sequential_double_vector_reader()
     test_random_access_double_vector_reader()
+    test_read_write_single_vector()
 
     os.remove(f"{base}.scp")
     os.remove(f"{base}.ark")
